% DemoSpectrumTwoCircles
%
% Overview:
%   Determine the spectrum of the Neumann-Poincare operator for 
%   two circles.
%
% References:
%   Mathematical and Computational Methods in Photonics - Tutorial Notes
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Matias Ruiz, Sanghyeon Yu
clear all;
close all;
clc;

% --------------------------------------------------
% Create the circles.
% --------------------------------------------------
nbPoints=100;
R=2;
dist=0.3;

D1 = ellipse(R,R, -R-dist/2,0, nbPoints);  % two circles
D2 = ellipse(R,R, +R+dist/2,0, nbPoints);

% --------------------------------------------------
% Numerically calcualte the spectrum of the Neumann-Poincare operator.
% --------------------------------------------------
K1 = Kstar(D1);
K2 = Kstar(D2);
KK11 = K1;
KK22 = K2;
KK12 = dndS(D1,D2);
KK21 = dndS(D2,D1);
KK2=[KK11 KK12 ; KK21 KK22];
eigen_num=sort((eig(KK2)),'descend');

% --------------------------------------------------
% Theoretically calcualte the spectrum of the Neumann-Poincare operator.
% --------------------------------------------------
alpha=sqrt(dist*(R+dist/4)); x0 = asinh(alpha/R);
n=20; 
eigen_theo = zeros(2*n+1,1);
for j=1:n
eigen_theo(1:2) = 0.5;
eigen_theo(4*j-1:4*j) = -1/2*exp(-2*x0*j);
eigen_theo(4*j+1:4*j+2) = 1/2*exp(-2*x0*j);
end

% --------------------------------------------------
% Display the eigenvalues.
% --------------------------------------------------
fprintf('\nIn theory | Numerically');
[eigen_theo(1:n), eigen_num(1:n)]