function Ks = Kstar(D)
% Ks = Kstar(curve) returns the matrix representing the kernel of Kstar com
% puted on the C2boundary D.
% Recall that K^star[f](x) = \frac{1}{2 \pi} \int_{\partial D} \frac{ <x - y, \nu_x> }{|x -
% y |^2 } f(y) d \sigma(y).

% Compute K, the adjoint of Ks
M = D.nbPoints;
Ks = zeros(M, M);

for j = 1:M
    xdoty = (D.points(1,j)-D.points(1,:)).*D.normal(1,j)...
        +(D.points(2,j)-D.points(2,:)).*D.normal(2,j);
    
    norm_xy_square = (D.points(1,j)-D.points(1,:)).^2 ...
        +(D.points(2,j)-D.points(2,:)).^2;
    
    %off-diagonal terms
    Ks(j, 1:j-1) = 1/(2*pi)* ...
        xdoty(1:j-1)./norm_xy_square(1:j-1).*D.sigma(1:j-1);
    Ks(j, j+1:M) = 1/(2*pi)* ...
        xdoty(j+1:M)./norm_xy_square(j+1:M).*D.sigma(j+1:M);
    
    %diagonal term
    Ks(j,j) = -1/(4*pi)* ...
        D.avec(:,j)'*D.normal(:,j)/(D.tvec_norm(j)^2)*D.sigma(j);
 
 %   if (1<j)&&(j<M)
 %       fprintf('--')
 %       Ks(j,j-1)
 %       Ks(j,j)
 %       Ks(j,j+1)
 %   end
end

end


% tangentNorm = D.tvec_norm(1)
% tangentNormSqr = tangentNorm^2
% dot(avec,normal)/tangentNormSqr
% dot(accel,normal)/tangentNormSqr
% x0 = D.points(:, 1)
% y1 = D.points(:, 2)
% xMinusY = x0 - y1
% normal = D.normal(:,1)
% accel = D.avec(:, 1)
% xMinusY(1)
% normXMinusY = sqrt(xMinusY(1)^2 + xMinusY(2)^2)
% normXMinusYSqr = normXMinusY^2
% 0./373
% 0.2/37
% 0.337
% 0.2/373
% dot(xMinusY, normal)/normXMinusYSqr
% dot(accel, normal)/tangentNormSqr
% dot(accel, normal)/tangentNormSqr/2
% dot(xMinusY, normal)
% normXMinusYSqr
% /tangentNormSqr
% dot(accel, normal)
% tangentNormSqr
% a  = 1/2*dot(accel, normal)/tangentNormSqr/2
% tangentNormB = D.tvec_norm(2)
% tangentNormBSqr = D.tvec_norm(2)^2
% accelB = D.accel(:,2)
% accelB = D.avec(:,2)
% normalB = D.normal(:,2)
% b  = 1/2*dot(accelB, normalB)/tangentNormBSqr/2
% b * sigma(2)
% b * D.sigma(2)
% 1/2/pi * b * D.sigma(2)
% a  = 1/4/pi*dot(accel, normal)/tangentNormSqr*D.sigma(1)
% b  = 1/4/pi*dot(accelB, normalB)/tangentNormBSqr*D.sigma(2)
% regular = 1/2/pi*dot(accel, normal)/tangentNormSqr*D.sigma(2)
% regular = 1/2/pi*dot(xMinusY, normal)/normXMinusYSqr*sigma(2)
% regular = 1/2/pi*dot(xMinusY, normal)/normXMinusYSqr*D.sigma(2)
% b  = 1/4/pi*dot(accelB, normalB)/tangentNormBSqr*D.sigma(2)